
from mandaye.auth.authform import AuthForm
from mandaye.configs.vincennes import auth_vincennes
from mandaye.filters.vincennes import Biblio

form_values = {
        'form_url': '/sezhame/page/connexion-abonne',
        'form_attrs': { 'id': 'dk-opac15-login-form', },
        'username_field': 'user',
        'password_field': 'password'
}

authform = AuthForm(auth_vincennes, form_values, 'biblio')
filters = Biblio()

biblio_mapping = [
        {
            'path': r'/',
            'on_response': [{'filter': filters.resp_html}]
        },
        {
            'path': r'/sezhame',
            'on_response': [{
                'filter': filters.resp_multicompte_html,
                'values': {
                    'associate_url': '/mandaye/associate',
                    'template': 'biblio/multicompte.html',
                    'site_name': 'biblio'
                    },

                },]
        },
        {
            'path': r'/mandaye/login$',
            'method': 'GET',
            'response': [{
                'filter': authform.login,
                'values': {
                    'associate_url': '/mandaye/associate',
                    },
                'condition': 'response.code==302',
                },]
        },
        {
            'path': r'/mandaye/associate$',
            'method': 'GET',
            'target': '/sezhame/page/connexion-abonne',
            'on_response': [{
                'filter': filters.resp_associate_login,
                'values': {
                    'action': '/mandaye/associate',
                    'template': 'biblio/associate.html',
                    'title': 'Associer un compte',
                    'title2': 'Associer une carte &agrave; votre compte citoyen Vincennes',
                    'first_msg': "C'est votre premi&egrave;re connexion via le compte citoyen. " + \
                            "Merci de saisir vos identifiants bilblioth&egrave;que pour que nous puissions les associer.",
                    'badlogin_msg': "Num&eacute;ro de carte ou/et mot de passe incorrects",
                    'failed_msg': "Vos identifiants pour la biblioth&egrave;que ne fonctionnent plus ! Merci de les ressaisir.",
                    },
                },
                {
                'filter': filters.resp_multicompte_html,
                'values': {
                    'associate_url': '/mandaye/associate',
                    'template': 'biblio/multicompte.html',
                    'site_name': 'biblio'
                    },

                },]
        },
        {
            'path':  r'/mandaye/associate$',
            'method': 'POST',
            'response': [
                {
                    'filter': authform.associate_submit,
                    'values': {
                        'connection_url': '/mandaye/connection',
                        'associate_url': '/mandaye/associate',
                        },
                    'condition': "response.code==302"
                    },
                ]
        },
        {
            'path': r'/mandaye/connection$',
            'method': 'GET',
            'response': [{
                'filter': auth_vincennes.connection,
                'values': {
                    'destination': 'https://test.vincennes.fr/comptecitoyen/auth',
                    'next_url': '/mandaye/login',
                    'service_name': 'biblio'
                    }
                }]
        },
        {
                'path': r'/sezhame/page/connexion-abonne$',
                'method': 'GET',
                'on_response': [{
                'filter': filters.resp_html_login_page,
                'values': {
                    'connection_url': '/mandaye/connection',
                    'template': 'biblio/login.html',
                    'title': 'Connexion via votre compte citoyen',
                    'msg': 'Blabla bla bla bla blabla bla bla blabla bla bla blabla bla bla bla'
                    }
                }]
        },
        {
            'path': r'/mandaye/change_user$',
            'method': 'GET',
            'response': [{
                'filter': authform.change_user,
                'values': {
                    'associate_url': '/mandaye/associate',
                    },
                }]
        },
        {
            'path': r'/mandaye/disassociate$',
            'method': 'GET',
            'response': [{
                'filter': authform.disassociate,
                'values': {
                    'next_url': '/sezhame',
                    },
                }]
        },
]


