
from mandaye.auth.authform import AuthForm
from mandaye.auth.vincennes import VincennesAuth

from mandaye.filters.vincennes import Duonet
from mandaye.filters.default import MandayeFilter

from mandaye.configs.vincennes import auth_vincennes

filters = Duonet()

form_values = {
        'form_url': 'Connect.aspx?key=CV4j27Em0dM%3d',
        'form_attrs': { 'name': 'form1' },
        'username_field': 'txtNomFoyer',
        'birthdate_field': 'txtDateNaissance',
        'password_field': 'txtCode',
}


authform = AuthForm(auth_vincennes, form_values, 'duonet')


duonet_mapping = [
        {
            'path': r'/Default.aspx$',
            'on_response': [{
                'filter': filters.resp_multicompte_html,
                'values': {
                    'associate_url': '/associate',
                    'template': 'duonet/multicompte.html',
                    'site_name': 'duonet'
                    },

                },]
        },
        {
            'path': r'/mandaye/change_user$',
            'method': 'GET',
            'response': [{
                'filter': authform.change_user,
                'values': {
                    'associate_url': '/associate',
                    },
                }]
        },
        {
            'path': r'/vincennes/login$',
            'method': 'GET',
            'response': [{
                'filter': authform.login,
                'values': {
                    'associate_url': '/associate',
                    },
                'condition': 'response.code==302',
                },]
        },
        {
            'path': r'/associate$',
            'method': 'GET',
            'target': '/Connect.aspx?key=CV4j27Em0dM%3d',
            'on_response': [{
                'filter': filters.resp_associate,
                'values': {
                    'action': '/associate',
                    'template': 'duonet/associate.html',
                    'title': 'Associer un compte au compte citoyen de Vincennes',
                    'first_msg': "C'est votre premi&egrave;re connexion via le compte citoyen. " + \
                            "Merci de saisir vos identifiants au conservatoire pour que nous puissions les associer.",
                    'badlogin_msg': "Mauvais identifiants",
                    'failed_msg': "Vos identifiants pour le conservatoire ne fonctionnent plus ! Merci de les ressaisir.",
                    },
                }]
        },
        {
            'path':  r'/associate$',
            'method': 'POST',
            'response': [
                {
                    'filter': authform.associate_submit,
                    'values': {
                        'connection_url': '/vincennes/connection',
                        'associate_url': '/associate',
                        },
                    'condition': "response.code==302"
                    },
                ]
        },
        {
            'path': r'/vincennes/connection$',
            'method': 'GET',
            'response': [{
                'filter': auth_vincennes.connection,
                'values': {
                    'destination': 'https://test.vincennes.fr/comptecitoyen/auth',
                    'next_url': '/vincennes/login',
                    'service_name': 'duonet'
                    }
                }]
        },
        {
            'path': r'/mandaye/disassociate$',
            'method': 'GET',
            'response': [{
                'filter': authform.disassociate,
                'values': {
                    'next_url': '/Default.aspx',
                    },
                }]
        },
        {
            'path': r'/Connect.aspx$',
            'method': 'GET',
            'on_response': [{
                'filter': filters.resp_login_page,
                'values': {
                    'connection_url': '/vincennes/connection',
                    'template': 'duonet/login.html',
                    'msg': 'blablablabla'
                    }
                }]
        },
        {
            'path': r'/$',
            'method': 'GET',
            'target': '/Connect.aspx?key=CV4j27Em0dM%3d',
            'on_response': [{
                'filter': filters.resp_login_page,
                'values': {
                    'connection_url': '/vincennes/connection',
                    'template': 'duonet/login.html',
                    'msg': 'blablablabla'
                    }
                }]
        },
]


