
from mandaye.auth.espacefamille import EspaceFamilleAuth
from mandaye.auth.vincennes import VincennesAuth

from mandaye.filters.vincennes import EspaceFamille
from mandaye.filters.default import MandayeFilter

from mandaye.configs.vincennes import auth_vincennes

folder_target = '/vincennes-noredirect'
filters = EspaceFamille()

form_values = {
        'form_action': '%s/login.do' % folder_target,
        'form_url': '%s/index.do' % folder_target,
        'form_attrs': { 'action': 'login.do', },
        'username_field': 'codeFamille',
        'password_field': 'motDePasse'
}

authform = EspaceFamilleAuth(auth_vincennes, form_values, 'espace_famille')

famille_mapping = [
        {
            'path': r'/$',
            'method': 'GET',
            'redirect': '%s/index.do' % folder_target
        },
        {
            'path': r'/mandaye/login$',
            'method': 'GET',
            'response': [{
                'filter': authform.login,
                'values': {
                    'associate_url': '%s/associate' % folder_target,
                    },
                'condition': 'response.code==302',
                },]
        },
        {
            'path': r'%s/associate$' % folder_target,
            'method': 'GET',
            'target': '%s/index.do' % folder_target,
            'on_response': [{
                'filter': filters.resp_associate,
                'values': {
                    'action': '%s/associate' % folder_target,
                    'template': 'famille_associate.html',
                    'title': 'Associer un compte au compte citoyen de Vincennes',
                    'first_msg': "C'est votre premi&egrave;re connexion via le compte citoyen. " + \
                            "Merci de saisir vos identifiants &agrave; l'espace famille pour que nous puissions les associer.",
                    'badlogin_msg': "Code famille et/ou mot de passe incorrects",
                    'failed_msg': "Vos identifiants pour l'espace famille ne fonctionnent plus ! Merci de les ressaisir.",
                    },
                }]
        },
        {
            'path':  r'%s/associate$' % folder_target,
            'method': 'POST',
            'response': [
                {
                    'filter': authform.associate_submit,
                    'values': {
                        'connection_url': '/mandaye/connection',
                        'associate_url': '%s/associate' % folder_target,
                        },
                    'condition': "response.code==302"
                    },
                ]
        },
        {
            'path': r'/mandaye/connection$',
            'method': 'GET',
            'response': [{
                'filter': auth_vincennes.connection,
                'values': {
                    'destination': 'https://test.vincennes.fr/comptecitoyen/auth',
                    'next_url': '/mandaye/login',
                    'service_name': 'famille'
                    }
                }]
        },
        {
            'path': r'%s/index.do$' % folder_target,
            'method': 'GET',
            'on_response': [{
            'filter': filters.resp_login_page,
            'values': {
                'connection_url': '/mandaye/connection',
                'template': 'famille/login.html',
                'title': 'Connexion via votre compte citoyen',
                'msg': 'Blabla bla bla bla blabla bla bla blabla bla bla blabla bla bla bla'
                }
            }]
        },
        {
            'path': r'%s/deconnexion.do$' % folder_target,
            'on_response': [{
            'filter': filters.resp_login_page,
            'values': {
                'connection_url': '/mandaye/connection',
                'template': 'famille/login.html',
                'title': 'Connexion via votre compte citoyen',
                'msg': 'Blabla bla bla bla blabla bla bla blabla bla bla blabla bla bla bla'
                }
            }]
        },
]

