
import Cookie
import mandaye
import re

from urlparse import parse_qs
from BeautifulSoup import BeautifulSoup

from mandaye.db import sql_session
from mandaye.models import Site, ExtUser, LocalUser
from mandaye.response import serve_template
from mandaye.response import _302, _401

def get_associate_form(env, values):
    associate_type = None
    error_msg = None
    msg = None
    if env['QUERY_STRING']:
        qs = parse_qs(env['QUERY_STRING'])
        if qs.has_key('type'):
            associate_type = qs['type'][0]
        if associate_type == 'badlogin':
            error_msg = values.get('badlogin_msg')
        elif associate_type == 'failed':
            error_msg = values.get('failed_msg')
        elif associate_type == 'first':
            msg = values.get('first_msg')
    form = serve_template(values.get('template'),
            msg=msg, error_msg=error_msg, **values)
    return form.encode('utf-8')

class Biblio:

    def resp_html_login_page(self, env, values, request, response):
        """ msg: response message body
        env: Mandaye environment
        """
        if '<div>Connexion utilisateur</div>' in response.msg:
            login = serve_template(values.get('template'), **values)
            response.msg = re.sub(r'(<span class="clear"></span>)',
                    r'\1 %s' % login.encode('utf-8'),
                    response.msg)
        return response

    def resp_html(self, env, values, request, response):
        """ Global html filter the Vincenne library
        This fix the fucking absolute url of the biblio site
        """
        content_type = response.headers.getheader('content-type')
        if response.msg and ('application/x-javascript' in content_type or \
                'text/html' in content_type or \
                'text/css'in content_type):
            response.msg = response.msg.replace(env["target"].geturl(),
                    '%s://%s' % (env["mandaye.scheme"], env["HTTP_HOST"]))
            if env["mandaye.scheme"] == 'https':
                response.msg = response.msg.replace('http://' + env["HTTP_HOST"],
                        '%s://%s' % (env["mandaye.scheme"], env["HTTP_HOST"]))
        return response

    def resp_associate_login(self, env, values, request, response):
        """ Use default login page to associate an account on the SSO
        """
        if response.msg and '<div class="inner">' in response.msg:
            form = get_associate_form(env, values)
            r = re.compile(r'<div class="inner">.*</div><!-- / inner -->',
                    re.MULTILINE|re.DOTALL)
            response.msg = re.sub(r, form, response.msg)
        return response

    def resp_multicompte_html(self, env, values, request, response):
        """ Modify response html to support multi accounts
        """
        login = env['beaker.session'].get('login')
        content_type = response.headers.getheader('content-type')
        if response.msg and login and 'text/html' in content_type and \
                '<h2><div>Mon compte</div></h2>' in response.msg:
            site_name = values.get('site_name')
            current_account = env['beaker.session'].get(site_name)
            ext_users = sql_session().query(ExtUser).\
                join(LocalUser).\
                join(Site).\
                filter(LocalUser.login==login).\
                filter(Site.name==site_name).\
                order_by(ExtUser.last_connection.desc()).\
                all()
            accounts = []
            for ext_user in ext_users:
                accounts.append(ext_user.login)
            regexp = re.compile(r'(<div id="opacaccount" class="summary">.*connecter</a></div></div>)',
                    re.MULTILINE|re.DOTALL)
            multi = serve_template(values.get('template'),
                    accounts=accounts, current_account=current_account, **values)
            response.msg = re.sub(regexp, r"\1 %s" % multi.encode('utf-8'), response.msg)
            response.msg = re.sub(r'(<div class="content"><div id="opacaccount" class="summary"><div class="name">)<b>(.*)</b>',
                    r'\1<b>\2 (%s)</b>' % current_account.encode('utf-8'),
                    response.msg)
        return response


class EspaceFamille:

    def resp_login_page(self, env, values, request, response):
        """ Modify the login_page form
        """
        if response.msg:
            login = serve_template(values.get('template'), **values)
            regexp = re.compile(
                    r'(type="submit" class="submit" value="Connectez-vous" /><br />.*</div>\s*</div>)',
                    re.MULTILINE|re.DOTALL)
            response.msg = re.sub(regexp,
                    r"\1%s" % login.encode('utf-8'), response.msg)
        return response

    def resp_associate(self, env, values, request, response):
        """docstring for resp_associate_login"""
        if response.msg:
            soup = BeautifulSoup(response.msg)
            div = soup.find('div', {'class': 'bloc-model-1'})
            if div:
                form = get_associate_form(env, values)
                div.replaceWith(form)
            response.msg = str(soup)
        return response


class Duonet:

    def resp_login_page(self, env, values, request, response):
        """ Modify login page to add the 'compte citoyen' connection
        """
        if response.msg and '<form name="form1"' in response.msg:
            login = serve_template(values.get('template'), **values)
            regexp = re.compile(
                    r'</table>.*<center>.*<span id="lblError".*</center>',
                    re.MULTILINE|re.DOTALL)
            response.msg = re.sub(regexp,
                    "</table>%s" % login.encode('utf-8'), response.msg)
        return response

    def resp_associate(self, env, values, request, response):
        """ Add the associate form in the page
        """
        if response.msg:
            soup = BeautifulSoup(response.msg)
            form = soup.find('form', {'name': 'form1'})
            if form:
                new_form = get_associate_form(env, values)
                form.replaceWith(new_form)
            response.msg = str(soup)
        return response

    def resp_multicompte_html(self, env, values, request, response):
        """ Modify response html to support multi accounts
        """
        site_name = values.get('site_name')
        login = env['beaker.session'].get('login')
        current_account = env['beaker.session'].get(site_name)
        if response.msg \
                and 'font-weight:bold;">Conservatoire de Vincennes' in response.msg\
                and login:
            ext_users = sql_session().query(ExtUser).\
                join(LocalUser).\
                join(Site).\
                filter(LocalUser.login==login).\
                filter(Site.name==site_name).\
                order_by(ExtUser.last_connection.desc()).\
                all()
            accounts = []
            for ext_user in ext_users:
                accounts.append(ext_user.login)
            soup = BeautifulSoup(response.msg)
            div = soup.find('div', {'style': 'padding-left:10px; background-color: #FEF8F5;'})
            multi = serve_template(values.get('template'),
                    accounts=accounts, current_account=current_account, **values)
            tbody = div.next.next
            #tr = tbody.findAll('tr')[0]
            tbody.append(multi)
            response.msg = str(soup)
        return response

