"""
Mandaye HTTP object: Response, Request and Headers
"""

import Cookie

class HTTPHeader(dict):
    """ Mandaye class to manage HTTP header
    """

    def load_httpmessage(self, headers):
        """ headers: HTTPMessage (httplib)
        """
        for key in headers.keys():
            self[key] = headers.getheaders(key)

    def load_from_list(self, headers):
        """ headers: list with the headers
        """
        for header in headers:
            self[header[0]] = [header[1]]

    def load_from_dict(self, headers):
        """
        """
        for key, value in headers.iteritems():
            self.addheader(key, value)

    def addheader(self, name, value):
        """ name: field name
        value: string with the field value """
        if isinstance(value, str):
            self[name] = [value]
        else:
            raise TypeError('Header value must be a string')

    def addheaders(self, name, values):
        """ name: field name
        values: list of field values """
        self[name] = value

    def getheader(self, name):
        if self.has_key(name):
            return self[name][0]
        else:
            return None

    def getheaders(self):
        res = {}
        for key, values in self.iteritems():
            res[key] = ', '.join(values)
        return res

    def addsetcookies(self, cookies):
        """ cookies: Cookie.SimpleCookie object """
        self['set-cookie'] = []
        for cookie in cookies.values():
            self['set-cookie'].append(cookie.output(header=""))

    def items(self):
        items = super(HTTPHeader, self).items()
        new_items = []
        for (key, values) in items:
            for value in values:
                new_items.append((key, value))
        return new_items

class HTTPRequest(object):

    def __init__(self, cookies=None, headers=None, req_method="GET", msg=None):
        """
        """
        self.cookies = cookies
        self.headers = headers
        self.msg = msg
        self.req_method = req_method
        if not headers:
            self.headers = HTTPHeader()
        if not cookies:
            self.cookies = Cookie.BaseCookie()


class HTTPResponse(object):
    """ Mandaye HTTP Response
    """

    def __init__(self, code=None, reason=None, headers=None, msg=None, cookies=None):
        """
        code: integer return code (200, 302, 404, ..)
        reason: string with http status (ex: OK, Not Found, ...)
        headers: dictionary with the headers
        msg: message body str
        """
        self.code = code
        self.reason = reason
        self.headers = headers
        self.msg = msg
        self.cookies = cookies
        if not headers:
            self.headers = HTTPHeader()
        if not cookies:
            self.cookies = Cookie.BaseCookie()

    def load_from_urllib(self, response):
        """ response: urrlib.addinfourl
        """
        self.headers.load_httpmessage(response.headers)
        for setcookie in response.headers.getheaders('set-cookie'):
            cookie = Cookie.SimpleCookie("Set-Cookie: %s" % setcookie)
            cookie = cookie.values()[0]
            if self.cookies.has_key(cookie.key):
                del self.cookies[cookie.key]
            self.cookies.load("Set-Cookie: %s" % setcookie)
        self.code = response.code
        self.reason = response.msg
        self.msg = response.read()

